@@ -294,17 +294,21 @@ const EXTENSION_TYPES: Map<&'static str, FileType> = phf_map! {
     "awk"        => FileType::Source, // awk
     "c"          => FileType::Source, // C/C++
     "c++"        => FileType::Source, // C/C++
+    "c++m"       => FileType::Source, // C/C++ module
     "cabal"      => FileType::Source, // Cabal
     "cc"         => FileType::Source, // C/C++
+    "ccm"        => FileType::Source, // C/C++ module
     "clj"        => FileType::Source, // Clojure
     "cp"         => FileType::Source, // C/C++ Xcode
     "cpp"        => FileType::Source, // C/C++
+    "cppm"       => FileType::Source, // C/C++ module
     "cr"         => FileType::Source, // Crystal
     "cs"         => FileType::Source, // C#
     "css"        => FileType::Source, // css
     "csx"        => FileType::Source, // C#
     "cu"         => FileType::Source, // CUDA
     "cxx"        => FileType::Source, // C/C++
+    "cxxm"       => FileType::Source, // C/C++ module
     "cypher"     => FileType::Source, // Cypher (query language)
     "d"          => FileType::Source, // D
     "dart"       => FileType::Source, // Dart
@@ -338,6 +342,7 @@ const EXTENSION_TYPES: Map<&'static str, FileType> = phf_map! {
     "inc"        => FileType::Source,
     "inl"        => FileType::Source, // C/C++ Microsoft
     "ipynb"      => FileType::Source, // Jupyter Notebook
+    "ixx"        => FileType::Source, // C/C++ module
     "java"       => FileType::Source, // Java
     "jl"         => FileType::Source, // Julia
     "js"         => FileType::Source, // JavaScript
