@@ -61,12 +61,9 @@ impl TerminalWidth {
         };
         #[cfg(windows)]
         let stdout_term_width = {
-            use std::os::windows::io::RawHandle;
             use windows_sys::Win32::System::Console::{GetStdHandle, STD_OUTPUT_HANDLE};
-            terminal_size::terminal_size_using_handle(unsafe {
-                GetStdHandle(STD_OUTPUT_HANDLE) as RawHandle
-            })
-            .map(|(w, _h)| w.0 as _)
+            terminal_size::terminal_size_using_handle(unsafe { GetStdHandle(STD_OUTPUT_HANDLE) })
+                .map(|(w, _h)| w.0 as _)
         };
 
         #[rustfmt::skip]
